#!/bin/bash

######################################################################################
#                                                                                    #
# Simple shell script to search the WSJT-X log file for previous QSOs by Callsign.   #
#                                                                                    #
######################################################################################


######################################################################################
# 08/04/22 - v0.1 - M0AWS - Basic code layout and function declarations              #
# 08/04/22 - v0.2 - M0AWS - Squashing bugs                                           #
# 08/04/22 - v0.3 - M0AWS - Code changes to get around old version of bash on MacOS  #
# 11/04/22 - v0.4 - M0AWS - Squashing bugs                                           #
#                                                                                    #
######################################################################################

##################################
# Declare Global Vars

VERSION="v0.4"
DEV="MikeT - M0AWS"
WSJTX_LOG="./wsjtx_log.adi"
DXCALLSIGN=""
RESULTS=""

##################################
# Declare Functions

function get_dx_callsign() {

	# User Input - Get callsign to search for
	echo "==========================================="
	echo "$0 $VERSION by $DEV"
	echo "==========================================="
	echo -n "Enter DX Callsign: "
	read DXCALLSIGN
	case $DXCALLSIGN in

		q|Q) cleanup
			;;

		  *) case $OSTYPE in

			darwin20) # MacOS
				  DXCALLSIGN=`echo $DXCALLSIGN | tr '[:lower:]' '[:upper:]'`
					;;

			       *) # Linux
				  DXCALLSIGN=`echo ${DXCALLSIGN^^}`
					;;
		     esac
			;;
	esac
}


function search_log() {

	# Handle nothing entered in get_dx_callsign
	case $DXCALLSIGN in

		"") return 1
			;;

		 *) # Search the logfile for the callsign entered in get_dx_callsign
		    RESULTS=`cat $WSJTX_LOG | grep $DXCALLSIGN | sed 's/ /*/g'`
			;;
	esac

	case $RESULTS in

		*$DXCALLSIGN*) echo "Search results for $DXCALLSIGN:"
			       for LINE in $RESULTS
					do
						DXCALL=`echo $LINE | sed 's/*/ /g' | grep -o 'call:[^[:space:]]*' | awk -F">" '{print $2}'`
                       				GRIDSQUARE=`echo $LINE | sed 's/*/ /g' | grep -o '<gridsquare[^[:space:]]*' | awk -F">" '{print $2}'`
                       				MODE=`echo $LINE | sed 's/*/ /g' | grep -o 'mode[^[:space:]]*' | awk -F">" '{print $2}'`
                       				RSTSENT=`echo $LINE | sed 's/*/ /g' | grep -o 'rst_sent[^[:space:]]*' | awk -F">" '{print $2}'`
                       				RSTRXD=`echo $LINE | sed 's/*/ /g' | grep -o 'rst_rcvd[^[:space:]]*' | awk -F">" '{print $2}'`
                       				QSODATE=`echo $LINE | sed 's/*/ /g' | grep -o 'qso_date:[^[:space:]]*' | awk -F">" '{print $2}' | sed -n -e "s_\(....\)\(..\)\(..\)_\3/\2/\1_p"`
                       				TIMEON=`echo $LINE | sed 's/*/ /g' | grep -o 'time_on[^[:space:]]*' | awk -F">" '{print $2}' | sed 's/../&:/g;s/:$//'`
                       				#QSODATEOFF=`echo $LINE | sed 's/*/ /g' | grep -o 'qso_date_off[^[:space:]]*' | awk -F">" '{print $2}'`
                       				TIMEOFF=`echo $LINE | sed 's/*/ /g' | grep -o 'time_off[^[:space:]]*' | awk -F">" '{print $2}' | sed 's/../&:/g;s/:$//'`
                       				BAND=`echo $LINE | sed 's/*/ /g' | grep -o 'band[^[:space:]]*' | awk -F">" '{print $2}'`
                       				#FREQ=`echo $LINE | sed 's/*/ /g' | grep -o 'freq[^[:space:]]*' | awk -F">" '{print $2}'`
						TXPWR=`echo $LINE | sed 's/*/ /g' | grep -o 'tx_pwr[^[:space:]]*' | awk -F">" '{print $2"w"}'`
                       				COMMENT=`echo $LINE | sed 's/*/ /g' | awk -F"<comment" '{print $2}' | awk -F">" '{print $2}' | sed 's/<operator:.*//g' | sed 's/<eor//g' | sed 's/miles/Miles/g'`
						
						echo "==============================================================================================================================================================="
						echo "| $DXCALL | $GRIDSQUARE | $QSODATE | $TIMEON | $TIMEOFF | SNR-TX: $RSTSENT | SNR-RX: $RSTRXD | $TXPWR | $BAND | $COMMENT "
						#echo "| $DXCALL | $GRIDSQUARE | $QSODATE | $TIMEON | $TIMEOFF | SNR-TX: $RSTSENT | SNR-RX: $RSTRXD | $TXPWR | $BAND | $FREQ | $COMMENT "

					done
					echo "==============================================================================================================================================================="
					echo "Press ENTER to start a new search or q/Q/CTRL-C to Exit"
					;;

		            *) echo "========================"
                               echo "$DXCALLSIGN not found!"
                               echo "========================"
                               echo "Press ENTER to start a new search or q/Q/CTRL-C to Exit"
			        ;;
	esac

}


function cleanup() {

	clear
	exit
    
}


##################################
# main()

clear
trap cleanup INT
while :
	do
		get_dx_callsign
		clear
		search_log
		case $? in

			1) # No search entered, do nothing!
				;;

			*) read input
			   case $input in

				q|Q) cleanup
				;;
			   esac
		esac
		clear
	done
exit
